# Copyright (c) 2000-2009, JPackage Project
# https://github.com/fedora-java/javapackages/blob/master/LICENSE
%bcond_with bootstrap

Summary:        A library for instantiating Java objects
Name:           objenesis
Version:        3.3
Release:        7%{?dist}
License:        Apache-2.0
URL:            http://objenesis.org/
Source0:        https://github.com/easymock/%{name}/archive/%{version}.tar.gz

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap-openjdk8
%else
BuildRequires:  maven-local-openjdk8
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
%endif

%if %{without bootstrap}
BuildRequires:  mvn(org.apache:apache-jar-resource-bundle)
%endif

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

%description
Objenesis is a small Java library that serves one purpose: to instantiate 
a new object of a particular class.
Java supports dynamic instantiation of classes using Class.newInstance(); 
however, this only works if the class has an appropriate constructor. There 
are many times when a class cannot be instantiated this way, such as when 
the class contains constructors that require arguments, that have side effects,
and/or that throw exceptions. As a result, it is common to see restrictions 
in libraries stating that classes must require a default constructor. 
Objenesis aims to overcome these restrictions by bypassing the constructor 
on object instantiation. Needing to instantiate an object without calling 
the constructor is a fairly specialized task, however there are certain cases 
when this is useful:
* Serialization, Remoting and Persistence - Objects need to be instantiated 
  and restored to a specific state, without invoking code.
* Proxies, AOP Libraries and Mock Objects - Classes can be sub-classed without 
  needing to worry about the super() constructor.
* Container Frameworks - Objects can be dynamically instantiated in 
  non-standard ways.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.



%prep
%autosetup

%pom_xpath_remove pom:addMavenDescriptor

%pom_remove_plugin :maven-timestamp-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r org.sonatype.plugins:nexus-staging-maven-plugin
%pom_xpath_remove "pom:dependency[pom:scope='test']" tck

%pom_xpath_remove pom:build/pom:extensions

rm tck/src/test/java/org/objenesis/tck/OsgiTest.java



%build
%mvn_build



%install
%mvn_install



%files -f .mfiles
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt



%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3-7
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3-6
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.3-5
- switched to non-bootstrap building

* Thu Apr 13 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.3-4
- rebuilt for opencloudos

* Fri Mar 24 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.1-3
- rebuild for opencloudos

* Fri Mar 24 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.1-2
- rebuild for opencloudos

* Fri Mar 24 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.1-1
- initial